:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

4.0.3 (not yet released)
------------------------

4.0.2 (November 22nd 2022)
--------------------------

* Fixed Pillow version with tests

4.0.1 (January 12th 2022)
-------------------------

* Compatibility with Django 4.0 and Grappelli 3.0

For further information, see :ref:`releasenotes`.
